/********************************************************************************
** Form generated from reading UI file 'ds_appearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DS_APPEARANCE_H
#define UI_DS_APPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_AppearancePage_Base
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *labelHeader;
    QGroupBox *gbHeadline;
    QVBoxLayout *vboxLayout1;
    QFrame *frameBGColor;
    QGridLayout *gridLayout;
    KColorButton *kcbHeaderBGColor;
    QLabel *tlBackgroundColor;
    QLabel *tlHeaderColor;
    KColorButton *kcbHeaderTextColor;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *AppearancePage_Base)
    {
        if (AppearancePage_Base->objectName().isEmpty())
            AppearancePage_Base->setObjectName("AppearancePage_Base");
        AppearancePage_Base->resize(500, 208);
        vboxLayout = new QVBoxLayout(AppearancePage_Base);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        labelHeader = new QLabel(AppearancePage_Base);
        labelHeader->setObjectName("labelHeader");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelHeader->sizePolicy().hasHeightForWidth());
        labelHeader->setSizePolicy(sizePolicy);
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(8);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        labelHeader->setFont(font);
        labelHeader->setFrameShape(QFrame::StyledPanel);
        labelHeader->setFrameShadow(QFrame::Sunken);
        labelHeader->setScaledContents(false);
        labelHeader->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        vboxLayout->addWidget(labelHeader);

        gbHeadline = new QGroupBox(AppearancePage_Base);
        gbHeadline->setObjectName("gbHeadline");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(gbHeadline->sizePolicy().hasHeightForWidth());
        gbHeadline->setSizePolicy(sizePolicy1);
        vboxLayout1 = new QVBoxLayout(gbHeadline);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(11, 11, 11, 11);
        frameBGColor = new QFrame(gbHeadline);
        frameBGColor->setObjectName("frameBGColor");
        gridLayout = new QGridLayout(frameBGColor);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        kcbHeaderBGColor = new KColorButton(frameBGColor);
        kcbHeaderBGColor->setObjectName("kcbHeaderBGColor");
        kcbHeaderBGColor->setEnabled(true);
        kcbHeaderBGColor->setProperty("color", QVariant(QColor(0, 0, 0)));

        gridLayout->addWidget(kcbHeaderBGColor, 0, 1, 1, 1);

        tlBackgroundColor = new QLabel(frameBGColor);
        tlBackgroundColor->setObjectName("tlBackgroundColor");
        tlBackgroundColor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(tlBackgroundColor, 0, 0, 1, 1);

        tlHeaderColor = new QLabel(frameBGColor);
        tlHeaderColor->setObjectName("tlHeaderColor");
        tlHeaderColor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(tlHeaderColor, 1, 0, 1, 1);

        kcbHeaderTextColor = new KColorButton(frameBGColor);
        kcbHeaderTextColor->setObjectName("kcbHeaderTextColor");
        kcbHeaderTextColor->setEnabled(true);
        kcbHeaderTextColor->setProperty("color", QVariant(QColor(255, 255, 255)));

        gridLayout->addWidget(kcbHeaderTextColor, 1, 1, 1, 1);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);


        vboxLayout1->addWidget(frameBGColor);


        vboxLayout->addWidget(gbHeadline);

        spacerItem1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(AppearancePage_Base);

        QMetaObject::connectSlotsByName(AppearancePage_Base);
    } // setupUi

    void retranslateUi(QWidget *AppearancePage_Base)
    {
        AppearancePage_Base->setWindowTitle(tr2i18n("Appearance Page", nullptr));
        labelHeader->setText(tr2i18n("Detailed Print Style - Appearance", nullptr));
        gbHeadline->setTitle(tr2i18n("Contact Headers", nullptr));
#if QT_CONFIG(tooltip)
        kcbHeaderBGColor->setToolTip(tr2i18n("Select the headline text background color", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcbHeaderBGColor->setWhatsThis(tr2i18n("Click this button to start a color chooser that will allow you set to the color for the headline background color.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcbHeaderBGColor->setText(QString());
        tlBackgroundColor->setText(tr2i18n("Headline background color:", nullptr));
        tlHeaderColor->setText(tr2i18n("Headline text color:", nullptr));
#if QT_CONFIG(tooltip)
        kcbHeaderTextColor->setToolTip(tr2i18n("Select the headline text color", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcbHeaderTextColor->setWhatsThis(tr2i18n("Click this button to start a color chooser that will allow you set to the color for the headline text.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcbHeaderTextColor->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class AppearancePage_Base: public Ui_AppearancePage_Base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DS_APPEARANCE_H

