/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kaddressbook.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KADDRESSBOOKADAPTOR_H
#define KADDRESSBOOKADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "mainwidget.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kaddressbook
 */
class KaddressbookAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kaddressbook")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kaddressbook\">\n"
"    <method name=\"newContact\"/>\n"
"    <method name=\"newGroup\"/>\n"
"    <method name=\"print\"/>\n"
"    <method name=\"printPreview\"/>\n"
"    <method name=\"configure\"/>\n"
"    <method name=\"handleCommandLine\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"arguments\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KaddressbookAdaptor(MainWidget *parent);
    ~KaddressbookAdaptor() override;

    inline MainWidget *parent() const
    { return static_cast<MainWidget *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void configure();
    void handleCommandLine(const QStringList &arguments);
    void newContact();
    void newGroup();
    void print();
    void printPreview();
Q_SIGNALS: // SIGNALS
};

#endif
