// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kaddressbook_configure_debug.h"


Q_LOGGING_CATEGORY(KADDRESSBOOK_CONFIGURE_LOG, "org.kde.pim.kaddressbook_configure", QtInfoMsg)

