/********************************************************************************
** Form generated from reading UI file 'rbs_appearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RBS_APPEARANCE_H
#define UI_RBS_APPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RingBinderStyleAppearanceForm_Base
{
public:
    QGridLayout *gridLayout;
    QGroupBox *GroupBox2;
    QVBoxLayout *verticalLayout;
    QCheckBox *cbPhoneNumbers;
    QCheckBox *cbEmails;
    QCheckBox *cbStreetAddresses;
    QCheckBox *cbOrganization;
    QCheckBox *cbBirthday;
    QCheckBox *cbNote;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *RingBinderStyleAppearanceForm_Base)
    {
        if (RingBinderStyleAppearanceForm_Base->objectName().isEmpty())
            RingBinderStyleAppearanceForm_Base->setObjectName("RingBinderStyleAppearanceForm_Base");
        RingBinderStyleAppearanceForm_Base->resize(620, 407);
        gridLayout = new QGridLayout(RingBinderStyleAppearanceForm_Base);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        GroupBox2 = new QGroupBox(RingBinderStyleAppearanceForm_Base);
        GroupBox2->setObjectName("GroupBox2");
        verticalLayout = new QVBoxLayout(GroupBox2);
        verticalLayout->setObjectName("verticalLayout");
        cbPhoneNumbers = new QCheckBox(GroupBox2);
        cbPhoneNumbers->setObjectName("cbPhoneNumbers");
        cbPhoneNumbers->setChecked(true);

        verticalLayout->addWidget(cbPhoneNumbers);

        cbEmails = new QCheckBox(GroupBox2);
        cbEmails->setObjectName("cbEmails");
        cbEmails->setChecked(true);

        verticalLayout->addWidget(cbEmails);

        cbStreetAddresses = new QCheckBox(GroupBox2);
        cbStreetAddresses->setObjectName("cbStreetAddresses");
        cbStreetAddresses->setChecked(true);

        verticalLayout->addWidget(cbStreetAddresses);

        cbOrganization = new QCheckBox(GroupBox2);
        cbOrganization->setObjectName("cbOrganization");

        verticalLayout->addWidget(cbOrganization);

        cbBirthday = new QCheckBox(GroupBox2);
        cbBirthday->setObjectName("cbBirthday");

        verticalLayout->addWidget(cbBirthday);

        cbNote = new QCheckBox(GroupBox2);
        cbNote->setObjectName("cbNote");

        verticalLayout->addWidget(cbNote);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        gridLayout->addWidget(GroupBox2, 0, 0, 1, 1);


        retranslateUi(RingBinderStyleAppearanceForm_Base);

        QMetaObject::connectSlotsByName(RingBinderStyleAppearanceForm_Base);
    } // setupUi

    void retranslateUi(QWidget *RingBinderStyleAppearanceForm_Base)
    {
        RingBinderStyleAppearanceForm_Base->setWindowTitle(tr2i18n("Appearance", nullptr));
        GroupBox2->setTitle(tr2i18n("Print Contact's Information", nullptr));
#if QT_CONFIG(tooltip)
        cbPhoneNumbers->setToolTip(tr2i18n("Print contact phone numbers", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbPhoneNumbers->setWhatsThis(tr2i18n("Check this box if you want contact phone numbers to be printed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbPhoneNumbers->setText(tr2i18n("Phone numbers", nullptr));
#if QT_CONFIG(tooltip)
        cbEmails->setToolTip(tr2i18n("Print contact email addresses", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbEmails->setWhatsThis(tr2i18n("Check this box if you want contact email addresses to be printed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbEmails->setText(tr2i18n("Email addresses", nullptr));
#if QT_CONFIG(tooltip)
        cbStreetAddresses->setToolTip(tr2i18n("Print contact street addresses", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbStreetAddresses->setWhatsThis(tr2i18n("Check this box if you want contact street addresses to be printed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbStreetAddresses->setText(tr2i18n("Postal addresses", nullptr));
#if QT_CONFIG(tooltip)
        cbOrganization->setToolTip(tr2i18n("Print contact organizations", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbOrganization->setWhatsThis(tr2i18n("Check this box if you want contact organizations to be printed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbOrganization->setText(tr2i18n("Organization", nullptr));
#if QT_CONFIG(tooltip)
        cbBirthday->setToolTip(tr2i18n("Print contact birthdays", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbBirthday->setWhatsThis(tr2i18n("Check this box if you want contact birthdays to be printed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbBirthday->setText(tr2i18n("Birthday", nullptr));
#if QT_CONFIG(tooltip)
        cbNote->setToolTip(tr2i18n("Print contact notes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbNote->setWhatsThis(tr2i18n("Check this box if you want contact notes to be printed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbNote->setText(tr2i18n("Note", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RingBinderStyleAppearanceForm_Base: public Ui_RingBinderStyleAppearanceForm_Base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RBS_APPEARANCE_H

