/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kaddressbook.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kaddressbookadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KaddressbookAdaptor
 */

KaddressbookAdaptor::KaddressbookAdaptor(MainWidget *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KaddressbookAdaptor::~KaddressbookAdaptor()
{
    // destructor
}

void KaddressbookAdaptor::configure()
{
    // handle method call org.kde.kaddressbook.configure
    parent()->configure();
}

void KaddressbookAdaptor::handleCommandLine(const QStringList &arguments)
{
    // handle method call org.kde.kaddressbook.handleCommandLine
    parent()->handleCommandLine(arguments);
}

void KaddressbookAdaptor::newContact()
{
    // handle method call org.kde.kaddressbook.newContact
    parent()->newContact();
}

void KaddressbookAdaptor::newGroup()
{
    // handle method call org.kde.kaddressbook.newGroup
    parent()->newGroup();
}

void KaddressbookAdaptor::print()
{
    // handle method call org.kde.kaddressbook.print
    parent()->print();
}

void KaddressbookAdaptor::printPreview()
{
    // handle method call org.kde.kaddressbook.printPreview
    parent()->printPreview();
}


#include "moc_kaddressbookadaptor.cpp"
