/********************************************************************************
** Form generated from reading UI file 'compactstyle.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPACTSTYLE_H
#define UI_COMPACTSTYLE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_CompactStyleForm_Base
{
public:
    QGridLayout *gridLayout;
    QGroupBox *gbFields;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *cbWithHomeAddress;
    QCheckBox *cbWithBusinessAddress;
    QCheckBox *cbWithBirthday;
    QCheckBox *cbWithEMail;
    QGroupBox *gbColors;
    QGridLayout *gridLayout_2;
    KColorButton *cbSecond;
    KColorButton *cbFirst;
    QLabel *lbCbFirst;
    QLabel *lbCbSecond;
    QCheckBox *cbAlternating;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CompactStyleForm_Base)
    {
        if (CompactStyleForm_Base->objectName().isEmpty())
            CompactStyleForm_Base->setObjectName("CompactStyleForm_Base");
        CompactStyleForm_Base->resize(620, 318);
        gridLayout = new QGridLayout(CompactStyleForm_Base);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gbFields = new QGroupBox(CompactStyleForm_Base);
        gbFields->setObjectName("gbFields");
        verticalLayout_2 = new QVBoxLayout(gbFields);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        cbWithHomeAddress = new QCheckBox(gbFields);
        cbWithHomeAddress->setObjectName("cbWithHomeAddress");

        verticalLayout->addWidget(cbWithHomeAddress);

        cbWithBusinessAddress = new QCheckBox(gbFields);
        cbWithBusinessAddress->setObjectName("cbWithBusinessAddress");

        verticalLayout->addWidget(cbWithBusinessAddress);

        cbWithBirthday = new QCheckBox(gbFields);
        cbWithBirthday->setObjectName("cbWithBirthday");

        verticalLayout->addWidget(cbWithBirthday);

        cbWithEMail = new QCheckBox(gbFields);
        cbWithEMail->setObjectName("cbWithEMail");

        verticalLayout->addWidget(cbWithEMail);


        verticalLayout_2->addLayout(verticalLayout);


        gridLayout->addWidget(gbFields, 1, 0, 1, 1);

        gbColors = new QGroupBox(CompactStyleForm_Base);
        gbColors->setObjectName("gbColors");
        gbColors->setTitle(QString::fromUtf8("GroupBox"));
        gridLayout_2 = new QGridLayout(gbColors);
        gridLayout_2->setObjectName("gridLayout_2");
        cbSecond = new KColorButton(gbColors);
        cbSecond->setObjectName("cbSecond");

        gridLayout_2->addWidget(cbSecond, 2, 1, 1, 1);

        cbFirst = new KColorButton(gbColors);
        cbFirst->setObjectName("cbFirst");

        gridLayout_2->addWidget(cbFirst, 1, 1, 1, 1);

        lbCbFirst = new QLabel(gbColors);
        lbCbFirst->setObjectName("lbCbFirst");

        gridLayout_2->addWidget(lbCbFirst, 1, 0, 1, 1);

        lbCbSecond = new QLabel(gbColors);
        lbCbSecond->setObjectName("lbCbSecond");

        gridLayout_2->addWidget(lbCbSecond, 2, 0, 1, 1);

        cbAlternating = new QCheckBox(gbColors);
        cbAlternating->setObjectName("cbAlternating");

        gridLayout_2->addWidget(cbAlternating, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 3, 0, 1, 1);


        gridLayout->addWidget(gbColors, 2, 0, 1, 1);


        retranslateUi(CompactStyleForm_Base);

        QMetaObject::connectSlotsByName(CompactStyleForm_Base);
    } // setupUi

    void retranslateUi(QWidget *CompactStyleForm_Base)
    {
        CompactStyleForm_Base->setWindowTitle(tr2i18n("Appearance", nullptr));
        gbFields->setTitle(tr2i18n("Fields", nullptr));
#if QT_CONFIG(tooltip)
        cbWithHomeAddress->setToolTip(tr2i18n("Print the home address, with home phone number and mobile phone number", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbWithHomeAddress->setWhatsThis(tr2i18n("Print the home address, with home phone number and mobile phone number", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbWithHomeAddress->setText(tr2i18n("with home address", nullptr));
#if QT_CONFIG(tooltip)
        cbWithBusinessAddress->setToolTip(tr2i18n("print the business address, with business phone number", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbWithBusinessAddress->setWhatsThis(tr2i18n("print the business address, with business phone number", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbWithBusinessAddress->setText(tr2i18n("with business address", nullptr));
#if QT_CONFIG(tooltip)
        cbWithBirthday->setToolTip(tr2i18n("Print the birthday", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbWithBirthday->setWhatsThis(tr2i18n("Print the birthday", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbWithBirthday->setText(tr2i18n("with birthday", nullptr));
#if QT_CONFIG(tooltip)
        cbWithEMail->setToolTip(tr2i18n("Print the preferred and the secondary e-mail fields", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbWithEMail->setWhatsThis(tr2i18n("Print the preferred and the secondary e-mail fields", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbWithEMail->setText(tr2i18n("with e-mail", nullptr));
#if QT_CONFIG(tooltip)
        lbCbFirst->setToolTip(tr2i18n("the first color, if alternating color is checked", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        lbCbFirst->setWhatsThis(tr2i18n("the first color, if alternating color is checked", nullptr));
#endif // QT_CONFIG(whatsthis)
        lbCbFirst->setText(tr2i18n("first color", nullptr));
#if QT_CONFIG(tooltip)
        lbCbSecond->setToolTip(tr2i18n("the second color, if alternating color is checked", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        lbCbSecond->setWhatsThis(tr2i18n("the second color, if alternating color is checked", nullptr));
#endif // QT_CONFIG(whatsthis)
        lbCbSecond->setText(tr2i18n("second color", nullptr));
#if QT_CONFIG(tooltip)
        cbAlternating->setToolTip(tr2i18n("Change the background color of every row", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbAlternating->setWhatsThis(tr2i18n("Change the background color of every row", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbAlternating->setText(tr2i18n("Alternating the background color", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CompactStyleForm_Base: public Ui_CompactStyleForm_Base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPACTSTYLE_H

